On 10/19/21 7:21 PM, Olivier Matz wrote:
On Tue, Oct 19, 2021 at 01:08:45PM +0300, Andrew Rybchenko wrote:
MEMPOOL_PG_NUM_DEFAULT and MEMPOOL_PG_SHIFT_MAX are not used.

Signed-off-by: Andrew Rybchenko <andrew.rybche...@oktetlabs.ru>

Fixes: fd943c764a63 ("mempool: deprecate xmem functions") ?

I think it is good idea. Without Cc to stable.


--- a/lib/mempool/rte_mempool.h
+++ b/lib/mempool/rte_mempool.h
@@ -116,10 +116,11 @@ struct rte_mempool_objsz {
  /* "MP_<name>" */
  #define       RTE_MEMPOOL_MZ_FORMAT   RTE_MEMPOOL_MZ_PREFIX "%s"
-#define MEMPOOL_PG_SHIFT_MAX (sizeof(uintptr_t) * CHAR_BIT - 1)
+#define        MEMPOOL_PG_SHIFT_MAX \
+       RTE_DEPRECATED(sizeof(uintptr_t) * CHAR_BIT - 1)
-/** Mempool over one chunk of physically continuous memory */
-#define        MEMPOOL_PG_NUM_DEFAULT  1
+/** Deprecated. Mempool over one chunk of physically continuous memory */
+#define        MEMPOOL_PG_NUM_DEFAULT  RTE_DEPRECATED(1)

Same comment than previous patches here.


Thanks Andrew for this series!

Thanks a lot for the review.

Reply via email to